@@ -1,6 +1,12 @@
+# frozen_string_literal: true
+
+# Ensure GLib is defined by GirFFI itself
+raise 'The module GLib was already defined elsewhere' if Kernel.const_defined? :GLib
+
 require 'gir_ffi/core'
 
-GirFFI.setup :GLib
+# Bypass check for existing modules
+GirFFI::Builders::ModuleBuilder.new('GLib').generate
 
 require 'ffi-glib/array'
 require 'ffi-glib/byte_array'
