@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require 'ffi'
 
 module GirFFI
@@ -15,7 +16,7 @@ module GirFFI
     end
 
     def self.to_native(value, _context)
-      TO_NATIVE.fetch(value)
+      TO_NATIVE.fetch(value ? true : false)
     end
 
     def self.size
