@@ -29,12 +29,13 @@ end
 FFI::Pointer.prepend GirFFI::FFIExt::Pointer
 
 FFI::Pointer.class_eval do
-  case FFI.type_size(:size_t)
-  when 4
-    alias_method :get_size_t, :get_uint32
-  when 8
-    alias_method :get_size_t, :get_uint64
-  end
+  size_t_getter = case FFI.type_size(:size_t)
+                  when 4
+                    :get_uint32
+                  when 8
+                    :get_uint64
+                  end
 
+  alias_method :get_size_t, size_t_getter
   alias_method :get_gtype, :get_size_t
 end
