@@ -1,4 +1,5 @@
 # frozen_string_literal: true
+
 require 'gir_ffi_test_helper'
 require 'gir_ffi/user_defined_object_info'
 
@@ -40,6 +41,12 @@ describe GirFFI::UserDefinedObjectInfo do
       impl = info.vfunc_implementations.first
       impl.implementation.must_equal implementation
     end
+
+    it 'provides a default implementation' do
+      info.install_vfunc_implementation :foo
+      impl = info.vfunc_implementations.first
+      impl.implementation.must_be_instance_of Proc
+    end
   end
 
   describe '#initialize' do
